@@ -832,8 +832,13 @@ def reproject_bbox(
 
     x_min, x_max, y_min, y_max = bbox_ogr
 
-    transformed_x_min, transformed_y_min, _z = transformer.TransformPoint(float(x_min), float(y_min))
-    transformed_x_max, transformed_y_max, _z = transformer.TransformPoint(float(x_max), float(y_max))
+    try:
+        transformed_x_min, transformed_y_min, _z = transformer.TransformPoint(x_min, y_min)
+        transformed_x_max, transformed_y_max, _z = transformer.TransformPoint(x_max, y_max)
+    except: # pylint: disable=bare-except
+        import pdb; pdb.set_trace()
+        transformed_x_min, transformed_y_min, _z = transformer.TransformPoint(float(x_min), float(y_min))
+        transformed_x_max, transformed_y_max, _z = transformer.TransformPoint(float(x_max), float(y_max))
 
     return [
         transformed_x_min,
@@ -857,7 +862,6 @@ def get_utm_zone_from_latlng(latlng, return_epsg=False):
     zone = round(((latlng[1] + 180) / 6) + 1)
     n_or_s = "S" if latlng[0] < 0 else "N"
 
-
     false_northing = "10000000" if n_or_s == "S" else "0"
     central_meridian = str(round(((zone * 6) - 180) - 3))
     epsg = f"32{'7' if n_or_s == 'S' else '6'}{str(zone)}"
@@ -932,7 +936,9 @@ def get_utm_zone_from_dataset(dataset):
 
     bbox = get_bbox_from_dataset(dataset)
     source_projection = get_projection_from_dataset(dataset)
-    target_projection = osr.SpatialReference(); target_projection.ImportFromEPSG(4326)
+    target_projection = osr.SpatialReference()
+    # target_projection.ImportFromEPSG(4326)
+    target_projection.ImportFromWkt('GEOGCRS["WGS 84",ENSEMBLE["World Geodetic System 1984 ensemble",MEMBER["World Geodetic System 1984 (Transit)"],MEMBER["World Geodetic System 1984 (G730)"],MEMBER["World Geodetic System 1984 (G873)"],MEMBER["World Geodetic System 1984 (G1150)"],MEMBER["World Geodetic System 1984 (G1674)"],MEMBER["World Geodetic System 1984 (G1762)"],MEMBER["World Geodetic System 1984 (G2139)"],ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1]],ENSEMBLEACCURACY[2.0]],PRIMEM["Greenwich",0,ANGLEUNIT["degree",0.0174532925199433]],CS[ellipsoidal,2],AXIS["geodetic latitude (Lat)",north,ORDER[1],ANGLEUNIT["degree",0.0174532925199433]],AXIS["geodetic longitude (Lon)",east,ORDER[2],ANGLEUNIT["degree",0.0174532925199433]],USAGE[SCOPE["Horizontal component of 3D system."],AREA["World."],BBOX[-90,-180,90,180]],ID["EPSG",4326]]')
 
     bbox = reproject_bbox(bbox, source_projection, target_projection)
     utm_zone = get_utm_zone_from_bbox(bbox)
@@ -953,7 +959,9 @@ def get_utm_zone_from_dataset_list(datasets):
     assert isinstance(datasets, (list, np.ndarray)), "datasets was not a valid list."
 
     latlng_bboxes = []
-    latlng_proj = osr.SpatialReference(); latlng_proj.ImportFromEPSG(4326)
+    latlng_proj = osr.SpatialReference()
+    # latlng_proj.ImportFromEPSG(4326)
+    latlng_proj.ImportFromWkt('GEOGCRS["WGS 84",ENSEMBLE["World Geodetic System 1984 ensemble",MEMBER["World Geodetic System 1984 (Transit)"],MEMBER["World Geodetic System 1984 (G730)"],MEMBER["World Geodetic System 1984 (G873)"],MEMBER["World Geodetic System 1984 (G1150)"],MEMBER["World Geodetic System 1984 (G1674)"],MEMBER["World Geodetic System 1984 (G1762)"],MEMBER["World Geodetic System 1984 (G2139)"],ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1]],ENSEMBLEACCURACY[2.0]],PRIMEM["Greenwich",0,ANGLEUNIT["degree",0.0174532925199433]],CS[ellipsoidal,2],AXIS["geodetic latitude (Lat)",north,ORDER[1],ANGLEUNIT["degree",0.0174532925199433]],AXIS["geodetic longitude (Lon)",east,ORDER[2],ANGLEUNIT["degree",0.0174532925199433]],USAGE[SCOPE["Horizontal component of 3D system."],AREA["World."],BBOX[-90,-180,90,180]],ID["EPSG",4326]]')
 
     for dataset in datasets:
         bbox = get_bbox_from_dataset(dataset)
@@ -974,14 +982,19 @@ def reproject_latlng_point_to_utm(latlng):
 
         Takes point in [lat, lng], returns [utm_x, utm_y].
     """
-    source_projection = osr.SpatialReference(); source_projection.ImportFromEPSG(4326)
+    source_projection = osr.SpatialReference()
+    # source_projection.ImportFromEPSG(4326)
+    source_projection.ImportFromWkt('GEOGCRS["WGS 84",ENSEMBLE["World Geodetic System 1984 ensemble",MEMBER["World Geodetic System 1984 (Transit)"],MEMBER["World Geodetic System 1984 (G730)"],MEMBER["World Geodetic System 1984 (G873)"],MEMBER["World Geodetic System 1984 (G1150)"],MEMBER["World Geodetic System 1984 (G1674)"],MEMBER["World Geodetic System 1984 (G1762)"],MEMBER["World Geodetic System 1984 (G2139)"],ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1]],ENSEMBLEACCURACY[2.0]],PRIMEM["Greenwich",0,ANGLEUNIT["degree",0.0174532925199433]],CS[ellipsoidal,2],AXIS["geodetic latitude (Lat)",north,ORDER[1],ANGLEUNIT["degree",0.0174532925199433]],AXIS["geodetic longitude (Lon)",east,ORDER[2],ANGLEUNIT["degree",0.0174532925199433]],USAGE[SCOPE["Horizontal component of 3D system."],AREA["World."],BBOX[-90,-180,90,180]],ID["EPSG",4326]]')
     target_projection = get_utm_zone_from_latlng(latlng)
 
     transformer = osr.CoordinateTransformation(
         source_projection, target_projection
     )
 
-    utm_x, utm_y, _utm_z = transformer.TransformPoint(float(latlng[0]), float(latlng[1]))
+    try:
+        utm_x, utm_y, _utm_z = transformer.TransformPoint(latlng[0], latlng[1])
+    except: # pylint: disable=bare-except
+        utm_x, utm_y, _utm_z = transformer.TransformPoint(float(latlng[0]), float(latlng[1]))
 
     return [utm_x, utm_y]
 
@@ -1018,7 +1031,8 @@ def additional_bboxes(bbox_ogr, projection_osr):
     original_projection.ImportFromWkt(projection_osr.ExportToWkt())
 
     latlng_projection = osr.SpatialReference()
-    latlng_projection.ImportFromEPSG(4326)
+    # latlng_projection.ImportFromEPSG(4326)
+    latlng_projection.ImportFromWkt('GEOGCRS["WGS 84",ENSEMBLE["World Geodetic System 1984 ensemble",MEMBER["World Geodetic System 1984 (Transit)"],MEMBER["World Geodetic System 1984 (G730)"],MEMBER["World Geodetic System 1984 (G873)"],MEMBER["World Geodetic System 1984 (G1150)"],MEMBER["World Geodetic System 1984 (G1674)"],MEMBER["World Geodetic System 1984 (G1762)"],MEMBER["World Geodetic System 1984 (G2139)"],ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1]],ENSEMBLEACCURACY[2.0]],PRIMEM["Greenwich",0,ANGLEUNIT["degree",0.0174532925199433]],CS[ellipsoidal,2],AXIS["geodetic latitude (Lat)",north,ORDER[1],ANGLEUNIT["degree",0.0174532925199433]],AXIS["geodetic longitude (Lon)",east,ORDER[2],ANGLEUNIT["degree",0.0174532925199433]],USAGE[SCOPE["Horizontal component of 3D system."],AREA["World."],BBOX[-90,-180,90,180]],ID["EPSG",4326]]')
 
     bbox_ogr_latlng = reproject_bbox(bbox_ogr, original_projection, latlng_projection)
     latlng_x_min, latlng_x_max, latlng_y_min, latlng_y_max = bbox_ogr_latlng
